==> occugene_1.4.0.zip: occugene/doc/occugene.R <==
###################################################
### chunk number 1: momments
###################################################
library("occugene")
n <- 60
p <- c(seq(10,1,-1),seq(10,1,-1),18)/124
p <- p/sum(p)
eMult(n,p)
varMult(n,p)


###################################################
### chunk number 2: approx momments
###################################################
eMult(n,p,iter=100,seed=4)
varMult(n,p,iter=100,seed=4)


###################################################
### chunk number 3: load
###################################################
data(sampleAnnotation)
data(sampleInsertions)
print(sampleAnnotation)
print(sampleInsertions)
a.data <- sampleAnnotation
experiment <- sampleInsertions


###################################################
### chunk number 4: et
###################################################
orf <- cbind(a.data$first,a.data$last)
clone <- experiment$position
etDelta(10,orf,clone)


###################################################
### chunk number 5: wj next
###################################################
orf <- cbind(a.data$first,a.data$last)
clone <- experiment$position
fFit(orf,clone,FALSE)
unbiasDelta0(10,orf,clone,iter=10,seed=4,alpha=0.05,TR=F)


###################################################
### chunk number 6: number essential will
###################################################
unbiasB0(orf,clone,iter=10,seed=4,alpha=0.05,TR=F)


###################################################
### chunk number 7: conversion
###################################################
newOrf <- occup2Negenes(orf,clone)
print(newOrf)

==> occugene_1.10.0.zip: occugene/doc/occugene.R <==
###################################################
### chunk number 1: momments
###################################################
#line 19 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKtiW1u/R.INSTALL6f218b5/occugene/inst/doc/occugene.Rnw"
library("occugene")
n <- 60
p <- c(seq(10,1,-1),seq(10,1,-1),18)/124
p <- p/sum(p)
eMult(n,p)
varMult(n,p)


###################################################
### chunk number 2: approx momments
###################################################
#line 30 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKtiW1u/R.INSTALL6f218b5/occugene/inst/doc/occugene.Rnw"
eMult(n,p,iter=100,seed=4)
varMult(n,p,iter=100,seed=4)


###################################################
### chunk number 3: load
###################################################
#line 37 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKtiW1u/R.INSTALL6f218b5/occugene/inst/doc/occugene.Rnw"
data(sampleAnnotation)
data(sampleInsertions)
print(sampleAnnotation)
print(sampleInsertions)
a.data <- sampleAnnotation
experiment <- sampleInsertions


###################################################
### chunk number 4: et
###################################################
#line 48 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKtiW1u/R.INSTALL6f218b5/occugene/inst/doc/occugene.Rnw"
orf <- cbind(a.data$first,a.data$last)
clone <- experiment$position
etDelta(10,orf,clone)


###################################################
### chunk number 5: wj next
###################################################
#line 56 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKtiW1u/R.INSTALL6f218b5/occugene/inst/doc/occugene.Rnw"
orf <- cbind(a.data$first,a.data$last)
clone <- experiment$position
fFit(orf,clone,FALSE)
unbiasDelta0(10,orf,clone,iter=10,seed=4,alpha=0.05,TR=F)


###################################################
### chunk number 6: number essential will
###################################################
#line 65 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKtiW1u/R.INSTALL6f218b5/occugene/inst/doc/occugene.Rnw"
unbiasB0(orf,clone,iter=10,seed=4,alpha=0.05,TR=F)


###################################################
### chunk number 7: conversion
###################################################
#line 71 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKtiW1u/R.INSTALL6f218b5/occugene/inst/doc/occugene.Rnw"
newOrf <- occup2Negenes(orf,clone)
print(newOrf)
